EXPORTS
	?Cancel@RPnPServiceDiscovery@@QAEXABVRPnPParameterBundle@@@Z @ 1 NONAME ; void RPnPServiceDiscovery::Cancel(class RPnPParameterBundle const &)
	?MessageDes@TControlMessage@@QBEABVTDesC8@@XZ @ 2 NONAME ; class TDesC8 const & TControlMessage::MessageDes(void) const
	?IsLast@TControlMessage@@QBEHXZ @ 3 NONAME ; int TControlMessage::IsLast(void) const
	?SetMaxLength@TControlMessage@@QAEXH@Z @ 4 NONAME ; void TControlMessage::SetMaxLength(int)
	??0RPnPServiceDiscovery@@QAE@XZ @ 5 NONAME ; RPnPServiceDiscovery::RPnPServiceDiscovery(void)
	?SendNotify@RPnPServicePublisher@@QAEXABVRPnPParameterBundle@@@Z @ 6 NONAME ; void RPnPServicePublisher::SendNotify(class RPnPParameterBundle const &)
	?Close@RControlChannel@@QAEXXZ @ 7 NONAME ; void RControlChannel::Close(void)
	?Open@RControlChannel@@QAEHAAVRSocketServ@@AAVRSubConnection@@IHIABUTConnectionDetails@@@Z @ 8 NONAME ; int RControlChannel::Open(class RSocketServ &, class RSubConnection &, unsigned int, int, unsigned int, struct TConnectionDetails const &)
	??1CPnPServiceDiscoveryBase@@UAE@XZ @ 9 NONAME ; CPnPServiceDiscoveryBase::~CPnPServiceDiscoveryBase(void)
	?Subscribe@RPnPServiceDiscovery@@QAEXABVRPnPParameterBundle@@@Z @ 10 NONAME ; void RPnPServiceDiscovery::Subscribe(class RPnPParameterBundle const &)
	?MessagePtr@TControlMessage@@QAEAAVTDes8@@XZ @ 11 NONAME ; class TDes8 & TControlMessage::MessagePtr(void)
	?PnPObserver@RPnPParameterBundle@@QBEPAVMPnPObserver@@XZ @ 12 NONAME ; class MPnPObserver * RPnPParameterBundle::PnPObserver(void) const
	?InitiateControl@RPnPServicePublisher@@QAEHAAVRControlChannel@@@Z @ 13 NONAME ; int RPnPServicePublisher::InitiateControl(class RControlChannel &)
	??1TControlMessage@@QAE@XZ @ 14 NONAME ; TControlMessage::~TControlMessage(void)
	?RegisterNotify@RPnPServiceDiscovery@@QAEXABVRPnPParameterBundle@@@Z @ 15 NONAME ; void RPnPServiceDiscovery::RegisterNotify(class RPnPParameterBundle const &)
	?Send@RControlChannel@@QAEXAAVTControlMessage@@AAVTRequestStatus@@@Z @ 16 NONAME ; void RControlChannel::Send(class TControlMessage &, class TRequestStatus &)
	?SetMessageDes@TControlMessage@@QAEXABVTDesC8@@@Z @ 17 NONAME ; void TControlMessage::SetMessageDes(class TDesC8 const &)
	?Describe@RPnPServiceDiscovery@@QAEXABVRPnPParameterBundle@@@Z @ 18 NONAME ; void RPnPServiceDiscovery::Describe(class RPnPParameterBundle const &)
	?Discover@RPnPServiceDiscovery@@QAEXABVRPnPParameterBundle@@@Z @ 19 NONAME ; void RPnPServiceDiscovery::Discover(class RPnPParameterBundle const &)
	?SetLast@TControlMessage@@QAEXXZ @ 20 NONAME ; void TControlMessage::SetLast(void)
	??1CPnPServicePublisherBase@@UAE@XZ @ 21 NONAME ; CPnPServicePublisherBase::~CPnPServicePublisherBase(void)
	?Open@RPnPParameterBundleBase@@QAEHXZ @ 22 NONAME ; int RPnPParameterBundleBase::Open(void)
	?Open@RPnPServiceDiscovery@@QAEHI@Z @ 23 NONAME ; int RPnPServiceDiscovery::Open(unsigned int)
	??0CPnPServiceDiscoveryBase@@IAE@XZ @ 24 NONAME ; CPnPServiceDiscoveryBase::CPnPServiceDiscoveryBase(void)
	?Close@RPnPParameterBundleBase@@QAEXXZ @ 25 NONAME ; void RPnPParameterBundleBase::Close(void)
	?MaxLength@TControlMessage@@QBEHXZ @ 26 NONAME ; int TControlMessage::MaxLength(void) const
	?ClearFlags@TControlMessage@@QAEXXZ @ 27 NONAME ; void TControlMessage::ClearFlags(void)
	?Recv@RControlChannel@@QAEXAAVTControlMessage@@AAVTRequestStatus@@@Z @ 28 NONAME ; void RControlChannel::Recv(class TControlMessage &, class TRequestStatus &)
	?Close@RPnPServicePublisher@@QAEXXZ @ 29 NONAME ; void RPnPServicePublisher::Close(void)
	?Open@RPnPServicePublisher@@QAEHI@Z @ 30 NONAME ; int RPnPServicePublisher::Open(unsigned int)
	?Publish@RPnPServicePublisher@@QAEXABVRPnPParameterBundle@@@Z @ 31 NONAME ; void RPnPServicePublisher::Publish(class RPnPParameterBundle const &)
	?SetPnPObserver@RPnPParameterBundle@@QAEXPAVMPnPObserver@@@Z @ 32 NONAME ; void RPnPParameterBundle::SetPnPObserver(class MPnPObserver *)
	?SetMessagePtr@TControlMessage@@QAEXAAVTDes8@@@Z @ 33 NONAME ; void TControlMessage::SetMessagePtr(class TDes8 &)
	??0RControlChannel@@QAE@XZ @ 34 NONAME ; RControlChannel::RControlChannel(void)
	?Close@RPnPServiceDiscovery@@QAEXXZ @ 35 NONAME ; void RPnPServiceDiscovery::Close(void)
	??0CPnPServicePublisherBase@@IAE@XZ @ 36 NONAME ; CPnPServicePublisherBase::CPnPServicePublisherBase(void)
	?InitiateControl@RPnPServiceDiscovery@@QAEHAAVRControlChannel@@ABVTDesC8@@@Z @ 37 NONAME ; int RPnPServiceDiscovery::InitiateControl(class RControlChannel &, class TDesC8 const &)
	??0RPnPServicePublisher@@QAE@XZ @ 38 NONAME ; RPnPServicePublisher::RPnPServicePublisher(void)
	??0TControlMessage@@QAE@XZ @ 39 NONAME ; TControlMessage::TControlMessage(void)

